pub struct CanonicalCompositionsNew<'data> {
pub trie: CodePointTrie<'data, u16>,
pub linear16: ZeroVec<'data, (u16, u16)>,
pub linear24: ZeroVec<'data, (char, char)>,
}Expand description
Non-Hangul canonical compositions, new format
๐ง This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. While the serde representation of data structs is guaranteed
to be stable, their Rust representation might not be. Use with caution.
Fields
trie: CodePointTrie<'data, u16>Trie from primary character to index into linear.
If the first character of the pair is
'a' | 'e' | 'i' | 'o' | 'u' | 'A' | 'E' | 'I' | 'O' | 'U',
the primary character is the second item in the pair. Otherwise,
the primary character is the first item in the pair.
linear16: ZeroVec<'data, (u16, u16)>Compositions that are fully within the BMP
linear24: ZeroVec<'data, (char, char)>Compositions with at least one character outside the BMP